@@ -363,8 +363,7 @@ KonqSessionManager::KonqSessionManager()
     const int interval = KonqSettings::autoSaveInterval();
     if (interval > 0) {
         m_autoSaveTimer.setInterval(interval * 1000);
-        connect(&m_autoSaveTimer, SIGNAL(timeout()), this,
-                SLOT(autoSaveSession()));
+        connect(&m_autoSaveTimer, &QTimer::timeout, this, &KonqSessionManager::autoSaveSession);
     }
     enableAutosave();
 
@@ -379,10 +378,41 @@ KonqSessionManager::~KonqSessionManager()
     delete m_sessionConfig;
 }
 
+void KonqSessionManager::restoreSessionSavedAtLogout()
+{
+    askUserToRestoreAutosavedAbandonedSessions();
+
+    m_preloadedWindowsNumber.clear();
+    int n = 1;
+    while (KonqMainWindow::canBeRestored(n)) {
+        const QString className = KXmlGuiWindow::classNameOfToplevel(n);
+
+        //The !m_preloadedWindowsNumber.contains(n) check avoid restoring preloaded windows
+        if (className == QLatin1String("KonqMainWindow") && !m_preloadedWindowsNumber.contains(n)) {
+            KonqMainWindow * mw = new KonqMainWindow();
+            mw->restore(n);
+
+            //m_preloadedWindowsNumber is set from the readGlobalProperties of the first (n==1) window.
+            //This means that the first window is always restored, even if it was preloaded (because readGlobalProperties
+            //is called from restore). For the first window, we need to check whether it was preloaded, and in that case
+            //delete it afterwards
+            if (n == 1 && m_preloadedWindowsNumber.contains(1)) {
+                mw->deleteLater();
+            }
+        } else  {
+            qCWarning(KONQUEROR_LOG) << "Unknown class" << className << "in session saved data!";
+        }
+        ++n;
+    }
+    m_preloadedWindowsNumber.clear();
+}
+
+
 // Don't restore preloaded konquerors
 void KonqSessionManager::slotCommitData(QSessionManager &sm)
 {
-    if (!m_autosaveEnabled) {
+    QList<KonqMainWindow*> const *windows = KonqMainWindow::mainWindowList();
+    if (std::all_of(windows->constBegin(), windows->constEnd(), [](KonqMainWindow *w){return w->isPreloaded();})) {
         sm.setRestartHint(QSessionManager::RestartNever);
     }
 }
@@ -683,3 +713,7 @@ bool KonqSessionManager::askUserToRestoreAutosavedAbandonedSessions()
     }
 }
 
+void KonqSessionManager::setPreloadedWindowsNumber(const QList<int> &numbers)
+{
+    m_preloadedWindowsNumber = numbers;
+}
